EagleEntry class
- Inheritance
-
- Object
- EagleBaseObject
- EagleEntry
Constructors
- EagleEntry.fromId(String id, EagleLibrary lib)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- library → EagleLibrary
-
no setter
- metadata → EntryMetadata
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
modify(
Function func) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
exists(
EagleLibrary lib, String id) → bool