EagleLibrary class

Constructors

EagleLibrary.fromPath(String path)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
metadata Metadata
final
mTime MTime
final
openedEntries List<EagleEntry>
no setter
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedFilters SavedFilters
final
tags Tags
final

Methods

getAllEntries() List<EagleEntry>
Get all entries as a list
getEntry(String id) EagleEntry?
Get an entry by its ID
iterEntries() Iterable<EagleEntry>
Iterate through all entries in the library
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Search entries by name, tags, and folders
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

isEagleLibrary(String path) int