Metadata class

Constructors

Metadata({required int modificationTime, required String applicationVersion, required List tagsGroups, required List quickAccess, required List smartFolders, required List<MetadataFolder> folders})
Metadata.fromJson(Map<String, dynamic> json)
factory

Properties

applicationVersion String
getter/setter pair
folders List<MetadataFolder>
final
hashCode int
The hash code for this object.
no setterinherited
modificationTime int
getter/setter pair
quickAccess List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smartFolders List
final
tagsGroups List
final

Methods

copy() Metadata
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited