EntryMetadata class

Constructors

EntryMetadata({required String id, required String name, required int size, required int btime, required int mtime, required String ext, required List<String> tags, required List<String> folders, required bool isDeleted, required int modificationTime, required int lastModified, required bool noPreview, required Map<String, dynamic> extras})
EntryMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

btime int
getter/setter pair
ext String
getter/setter pair
extras Map<String, dynamic>
getter/setter pair
folders List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isDeleted bool
getter/setter pair
lastModified int
getter/setter pair
modificationTime int
getter/setter pair
mtime int
getter/setter pair
name String
getter/setter pair
noPreview bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair
tags List<String>
final

Methods

copy() EntryMetadata
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited