MetadataFolder class

Inheritance

Constructors

MetadataFolder({required String id, required String name, String description = '', required int modificationTime, List<MetadataFolder> children = const [], List tags = const [], String password = '', String passwordTips = ''})
MetadataFolder.fromJson(Map<String, dynamic> json)
factory

Properties

children List<MetadataFolder>
final
description String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
modificationTime int
getter/setter pairinherited
name String
getter/setter pairinherited
password String
getter/setter pair
passwordTips String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List
final

Methods

copy() MetadataFolder
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited