MetadataSmartFolderCondition class

Constructors

MetadataSmartFolderCondition({required List<MetadataSmartFolderRule> rules, required String match, required String boolean, required String $$hashKey})
MetadataSmartFolderCondition.fromJson(Map<String, dynamic> json)
factory

Properties

$$hashKey String
getter/setter pair
boolean String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
match String
getter/setter pair
rules List<MetadataSmartFolderRule>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited