Metadata class
Constructors
Properties
- applicationVersion ↔ String
-
getter/setter pair
-
folders
→ List<
MetadataFolder> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- modificationTime ↔ int
-
getter/setter pair
- quickAccess → List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smartFolders → List
-
final
-
final
Methods
-
copy(
) → Metadata -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited